@@ -33,6 +33,7 @@ import fs
 import socketio
 from flask import g, jsonify, request, render_template
 from flask import send_from_directory, abort
+from flask_cors import CORS
 from flask_httpauth import HTTPBasicAuth
 from validate_email import validate_email
 from werkzeug.utils import secure_filename
@@ -45,6 +46,7 @@ from mslib.utils import conditional_decorator
 from mslib.index import app_loader
 
 APP = app_loader(__name__)
+CORS(APP, origins=mscolab_settings.CORS_ORIGINS if hasattr(mscolab_settings, "CORS_ORIGINS") else ["*"])
 
 # set the project root directory as the static folder
 # ToDo needs refactoring on a route without using of static folder
@@ -91,7 +93,7 @@ if mscolab_settings.__dict__.get('enable_basic_http_authentication', False):
 
 def initialize_managers(app):
     sockio, cm, fm = setup_managers(app)
-    # initiatializing socketio and db
+    # initializing socketio and db
     app.wsgi_app = socketio.Middleware(socketio.server, app.wsgi_app)
     sockio.init_app(app)
     db.init_app(app)
@@ -133,7 +135,7 @@ def verify_user(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         try:
-            user = User.verify_auth_token(request.form.get('token', False))
+            user = User.verify_auth_token(request.values.get('token', False))
         except TypeError:
             logging.debug("no token in request form")
             abort(404)
@@ -217,8 +219,8 @@ def delete_user():
 @APP.route("/messages", methods=["GET"])
 @verify_user
 def messages():
-    timestamp = request.form.get("timestamp", "1970-01-01, 00:00:00")
-    p_id = request.form.get("p_id", None)
+    timestamp = request.values.get("timestamp", "1970-01-01, 00:00:00")
+    p_id = request.values.get("p_id", None)
     chat_messages = cm.get_messages(p_id, timestamp)
     return jsonify({"messages": chat_messages})
 
@@ -231,6 +233,9 @@ def message_attachment():
     p_id = request.form.get("p_id", None)
     message_type = MessageType(int(request.form.get("message_type")))
     user = g.user
+    users = fm.fetch_users_without_permission(int(p_id), user.id)
+    if users is False:
+        return jsonify({"success": False, "message": "Could not send message. No file uploaded."})
     if file is not None:
         with fs.open_fs('/') as home_fs:
             file_dir = fs.path.join(APP.config['UPLOAD_FOLDER'], p_id)
@@ -365,7 +370,7 @@ def update_project():
 @APP.route('/project_details', methods=["GET"])
 @verify_user
 def get_project_details():
-    p_id = request.form.get('p_id', None)
+    p_id = request.values.get('p_id', None)
     user = g.user
     return json.dumps(fm.get_project_details(int(p_id), user))
 
@@ -387,7 +392,7 @@ def undo_ftml():
 @APP.route("/users_without_permission", methods=["GET"])
 @verify_user
 def get_users_without_permission():
-    p_id = request.form.get('p_id', None)
+    p_id = request.values.get('p_id', None)
     u_id = g.user.id
     users = fm.fetch_users_without_permission(int(p_id), u_id)
     if users is False:
@@ -399,7 +404,7 @@ def get_users_without_permission():
 @APP.route("/users_with_permission", methods=["GET"])
 @verify_user
 def get_users_with_permission():
-    p_id = request.form.get('p_id', None)
+    p_id = request.values.get('p_id', None)
     u_id = g.user.id
     users = fm.fetch_users_with_permission(int(p_id), u_id)
     if users is False:
